@@ -24,10 +24,10 @@
 #include "dgn-overview.h"
 #include "dgn-proclayouts.h"
 #include "files.h"
-#include "godcompanions.h" // hep stuff
-#include "godpassive.h" // passive_t::slow_abyss
+#include "god-companions.h" // hep stuff
+#include "god-passive.h" // passive_t::slow_abyss
 #include "hiscores.h"
-#include "itemprop.h"
+#include "item-prop.h"
 #include "items.h"
 #include "libutil.h"
 #include "mapmark.h"
@@ -51,7 +51,7 @@
 #include "terrain.h"
 #include "tiledef-dngn.h"
 #include "tileview.h"
-#include "timed_effects.h"
+#include "timed-effects.h"
 #include "traps.h"
 #include "travel.h"
 #include "view.h"
@@ -714,7 +714,7 @@ static void _abyss_wipe_square_at(coord_def p, bool saveMonsters=false)
     // Delete cloud.
     delete_cloud(p);
 
-    env.pgrid(p)        = 0;
+    env.pgrid(p)        = terrain_property_t{};
     env.grid_colours(p) = 0;
 #ifdef USE_TILE
     env.tile_bk_fg(p)   = 0;
@@ -774,6 +774,42 @@ static void _abyss_move_masked_vaults_by_delta(const coord_def delta)
     }
 }
 
+/**
+ * Updates the destination of a transporter that has been shifted to a new
+ * center. Assumes that the transporter itself and its position marker have
+ * already been moved.
+ *
+ * @param pos            Transporter's new (and current) location.
+ * @param source_center  Center of where the transporter's vault area was
+ *                       shifted from.
+ * @param target_center  Center of where the transporter's vault area is being
+ *                       shifted to.
+ * @param shift_area     A map_bitmask of the entire area being shifted.
+
+ */
+static void _abyss_update_transporter(const coord_def &pos,
+                                      const coord_def &source_centre,
+                                      const coord_def &target_centre,
+                                      const map_bitmask &shift_area)
+{
+    if (grd(pos) != DNGN_TRANSPORTER)
+        return;
+
+    map_position_marker *marker =
+        get_position_marker_at(pos, DNGN_TRANSPORTER);
+    if (!marker || marker->dest == INVALID_COORD)
+        return;
+
+    // Original destination is not being preserved, so disable the transporter.
+    if (!shift_area.get(marker->dest))
+    {
+        marker->dest = INVALID_COORD;
+        return;
+    }
+
+    marker->dest = marker->dest - source_centre + target_centre;
+}
+
 // Moves the player, monsters, terrain and items in the square (circle
 // in movement distance) around the player with the given radius to
 // the square centred on target_centre.
@@ -787,6 +823,7 @@ static void _abyss_move_entities(coord_def target_centre,
 {
     const coord_def source_centre = you.pos();
     const coord_def delta = (target_centre - source_centre).sgn();
+    const map_bitmask original_area_mask = *shift_area_mask;
 
     // When moving a region, walk backward to handle overlapping
     // ranges correctly.
@@ -824,6 +861,8 @@ static void _abyss_move_entities(coord_def target_centre,
                 // Wipe the dstination clean before dropping things on it.
                 _abyss_wipe_square_at(dst);
                 _abyss_move_entities_at(src, dst);
+                _abyss_update_transporter(dst, source_centre, target_centre,
+                                          original_area_mask);
             }
             else
             {
@@ -1103,7 +1142,7 @@ static cloud_type _cloud_from_feat(const dungeon_feature_type &ft)
         case DNGN_SLIMY_WALL:
         case DNGN_STONE_WALL:
         case DNGN_PERMAROCK_WALL:
-            return coinflip() ? CLOUD_BLUE_SMOKE : CLOUD_PURPLE_SMOKE;
+            return random_choose(CLOUD_BLUE_SMOKE, CLOUD_PURPLE_SMOKE);
         case DNGN_CLEAR_ROCK_WALL:
         case DNGN_CLEAR_STONE_WALL:
         case DNGN_CLEAR_PERMAROCK_WALL:
@@ -1437,7 +1476,6 @@ static void abyss_area_shift()
 
     // And allow monsters in transit another chance to return.
     place_transiting_monsters();
-    place_transiting_items();
 
     check_map_validity();
 }
@@ -1521,7 +1559,6 @@ static void _abyss_generate_new_area()
 
     los_changed();
     place_transiting_monsters();
-    place_transiting_items();
 }
 
 // Check if there is a path between the abyss centre and an exit location.
@@ -1701,8 +1738,8 @@ static bool _spawn_corrupted_servant_near(const coord_def &pos)
     {
         const int offsetX = random2avg(4, 3) + random2(3);
         const int offsetY = random2avg(4, 3) + random2(3);
-        const coord_def p(pos.x + (coinflip()? offsetX : -offsetX),
-                          pos.y + (coinflip()? offsetY : -offsetY));
+        const coord_def p(pos.x + random_choose(offsetX, -offsetX),
+                          pos.y + random_choose(offsetY, -offsetY));
         if (!in_bounds(p) || actor_at(p))
             continue;
 
