@@ -13,15 +13,17 @@
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
+#include <functional>
 
 #include "areas.h"
 #include "branch.h"
 #include "colour.h"
 #include "coordit.h"
 #include "database.h"
-#include "goditem.h"
-#include "itemname.h"
-#include "itemprop.h"
+#include "god-item.h"
+#include "item-name.h"
+#include "item-prop.h"
+#include "item-status-flag-type.h"
 #include "items.h"
 #include "libutil.h"
 #include "makeitem.h"
@@ -33,6 +35,15 @@
 #include "stringutil.h"
 #include "unicode.h"
 
+// Putting this here since art-enum.h is generated.
+
+// Make sure there's enough room in you.unique_items to hold all
+// the unrandarts.
+COMPILE_CHECK(NUM_UNRANDARTS < MAX_UNRANDARTS);
+// Non-artefact brands and unrandart indexes both go into
+// item.special, so make sure they don't overlap.
+COMPILE_CHECK((int) NUM_SPECIAL_WEAPONS < (int) UNRAND_START);
+
 static bool _god_fits_artefact(const god_type which_god, const item_def &item,
                                bool name_check_only = false)
 {
@@ -69,7 +80,7 @@ static bool _god_fits_artefact(const god_type which_god, const item_def &item,
                  || brand == SPWPN_REAPING
                  || brand == SPWPN_CHAOS
                  || is_demonic(item)
-                 || artefact_property(item, ARTP_CURSE) != 0))
+                 || artefact_property(item, ARTP_CURSE)))
     {
         return false;
     }
@@ -343,6 +354,7 @@ static void _populate_armour_intrinsic_artps(const armour_type arm,
     proprt[ARTP_NEGATIVE_ENERGY] += armour_type_prop(arm, ARMF_RES_NEG);
     proprt[ARTP_POISON] += armour_type_prop(arm, ARMF_RES_POISON);
     proprt[ARTP_ELECTRICITY] += armour_type_prop(arm, ARMF_RES_ELEC);
+    proprt[ARTP_RCORR] += armour_type_prop(arm, ARMF_RES_CORR);
     proprt[ARTP_MAGIC_RESISTANCE] += armour_type_prop(arm, ARMF_RES_MAGIC);
     proprt[ARTP_STEALTH] += armour_type_prop(arm, ARMF_STEALTH);
     proprt[ARTP_REGENERATION] += armour_type_prop(arm, ARMF_REGENERATION);
@@ -651,9 +663,6 @@ static const artefact_prop_data artp_data[] =
         []() { return 1; }, nullptr, 0, 0 },
     { "+Fly", ARTP_VAL_BOOL, 15,    // ARTP_FLY,
         []() { return 1; }, nullptr, 0, 0 },
-#if TAG_MAJOR_VERSION > 34
-    { "+Fog", ARTP_VAL_BOOL, 0, nullptr, nullptr, 0, 0 }, // ARTP_FOG,
-#endif
     { "+Blink", ARTP_VAL_BOOL, 15,  // ARTP_BLINK,
         []() { return 1; }, nullptr, 0, 0 },
     { "+Rage", ARTP_VAL_BOOL, 15,   // ARTP_BERSERK,
@@ -958,7 +967,7 @@ static bool _init_artefact_properties(item_def &item)
 
     for (int i = 0; i < ART_PROPERTIES; i++)
     {
-        if (i == ARTP_CURSE && prop[i] < 0)
+        if (i == ARTP_CURSE && prop[i])
         {
             do_curse_item(item);
             continue;
@@ -966,6 +975,7 @@ static bool _init_artefact_properties(item_def &item)
         rap[i] = static_cast<short>(prop[i]);
     }
 
+
     return true;
 }
 
@@ -1066,9 +1076,9 @@ static int _artefact_num_props(const artefact_properties_t &proprt)
 {
     int num = 0;
 
-    // Count all properties, but exclude self-cursing.
+    // Count all properties.
     for (int i = 0; i < ARTP_NUM_PROPERTIES; ++i)
-        if (i != ARTP_CURSE && proprt[i] != 0)
+        if (proprt[i] != 0)
             num++;
 
     return num;
@@ -1505,7 +1515,7 @@ static bool _randart_is_conflicting(const item_def &item,
     if (item.base_type == OBJ_WEAPONS
         && get_weapon_brand(item) == SPWPN_HOLY_WRATH
         && (is_demonic(item)
-            || proprt[ARTP_CURSE] != 0))
+            || proprt[ARTP_CURSE]))
     {
         return true;
     }
@@ -1742,7 +1752,7 @@ bool make_item_unrandart(item_def &item, int unrand_index)
     _artefact_setup_prop_vectors(item);
     _init_artefact_properties(item);
 
-    if (unrand->prpty[ARTP_CURSE] != 0)
+    if (unrand->prpty[ARTP_CURSE])
         do_curse_item(item);
 
     // get artefact appearance
