@@ -8,13 +8,15 @@
 #include "butcher.h"
 
 #include "bloodspatter.h"
+#include "confirm-butcher-type.h"
 #include "command.h"
 #include "delay.h"
 #include "env.h"
 #include "food.h"
-#include "godconduct.h"
-#include "itemname.h"
-#include "itemprop.h"
+#include "god-conduct.h"
+#include "item-name.h"
+#include "item-prop.h"
+#include "item-status-flag-type.h"
 #include "items.h"
 #include "libutil.h"
 #include "macro.h"
