@@ -7,21 +7,23 @@
 
 #include "crash.h"
 
-#ifdef USE_UNIX_SIGNALS
-#include <csignal>
-#include <sys/time.h>
+#if defined(UNIX)
+#include <unistd.h>
+#include <sys/param.h>
+        #define BACKTRACE_SUPPORTED
 #endif
 
+#ifdef USE_UNIX_SIGNALS
+#include <sys/time.h>
+#include <csignal>
+#endif
+
+
 #ifndef TARGET_OS_WINDOWS
 # include <cerrno>
 # include <sys/wait.h>
 #endif
 
-#if defined(UNIX)
-#include <unistd.h>
-        #define BACKTRACE_SUPPORTED
-#endif
-
 #ifdef BACKTRACE_SUPPORTED
 #if defined(TARGET_CPU_MIPS) || \
     defined(TARGET_OS_FREEBSD) || \
@@ -271,12 +273,22 @@ void init_crash_handler()
 void dump_crash_info(FILE* file)
 {
 #if defined(UNIX)
-    const char *name = strsignal(_crash_signal);
+    #ifdef TARGET_OS_FREEBSD
+        // FreeBSD's strsignal was not working properly so we just check
+        // to make sure that the signal is in the available list of signals,
+        // and then look it up in the table of signal handler names that
+        // FreeBSD exposes.
+        const char *name = nullptr;
+        if (_crash_signal >= SIGHUP && _crash_signal <= SIGLIBRT)
+            name = sys_signame[_crash_signal];
+    #else
+        const char *name = strsignal(_crash_signal);
+    #endif
+
     if (name == nullptr)
         name = "INVALID";
 
-    fprintf(file, "Crash caused by signal #%d: %s\n\n", _crash_signal,
-            name);
+    fprintf(file, "Crash caused by signal #%d: %s\n\n", _crash_signal, name);
 #endif
 }
 
