@@ -22,12 +22,13 @@
 #include "dungeon.h"
 #include "end.h"
 #include "env.h"
-#include "godabil.h"
+#include "god-abil.h"
 #include "initfile.h"
 #include "invent.h"
-#include "itemname.h"
-#include "itemprop.h"
-#include "itemprop-enum.h"
+#include "item-name.h"
+#include "item-prop.h"
+#include "item-prop-enum.h"
+#include "item-status-flag-type.h"
 #include "items.h"
 #include "libutil.h"
 #include "maps.h"
@@ -61,7 +62,6 @@ enum item_base_type
     ITEM_ARMOUR,
     ITEM_JEWELLERY,
     ITEM_MISCELLANY,
-    ITEM_RODS,
     ITEM_BOOKS,
     ITEM_ARTEBOOKS,
     ITEM_MANUALS,
@@ -153,10 +153,6 @@ static const vector<string> item_fields[NUM_ITEM_BASE_TYPES] = {
     { // ITEM_MISCELLANY
         "Num", "NumMin", "NumMax", "NumSD", "MiscPlus"
     },
-    { // ITEM_RODS
-        "Num", "NumMin", "NumMax", "NumSD", "NumHeldMons",
-        "RodMana", "RodRecharge", "NumCursed"
-    },
     { // ITEM_BOOKS
         "Num", "NumMin", "NumMax", "NumSD"
     },
@@ -240,9 +236,6 @@ static item_base_type _item_base_type(const item_def &item)
     case OBJ_JEWELLERY:
         type = ITEM_JEWELLERY;
         break;
-    case OBJ_RODS:
-        type = ITEM_RODS;
-        break;
     default:
         type = ITEM_IGNORE;
         break;
@@ -285,9 +278,6 @@ static object_class_type _item_orig_base_type(item_base_type base_type)
     case ITEM_JEWELLERY:
         type = OBJ_JEWELLERY;
         break;
-    case ITEM_RODS:
-        type = OBJ_RODS;
-        break;
     case ITEM_MISCELLANY:
         type = OBJ_MISCELLANY;
         break;
@@ -574,7 +564,6 @@ static bool _item_track_curse(item_base_type base_type)
     case ITEM_STAVES:
     case ITEM_ARMOUR:
     case ITEM_JEWELLERY:
-    case ITEM_RODS:
         return true;
     default:
         return false;
@@ -620,7 +609,6 @@ static bool _item_track_monster(item_base_type base_type)
     case ITEM_WEAPONS:
     case ITEM_STAVES:
     case ITEM_ARMOUR:
-    case ITEM_RODS:
     case ITEM_MISSILES:
     case ITEM_JEWELLERY:
         return true;
@@ -678,11 +666,6 @@ void objstat_record_item(const item_def &item)
     case ITEM_WANDS:
         all_plus_f = "WandCharges";
         break;
-    case ITEM_RODS:
-        _record_item_stat(cur_lev, itype, "RodMana",
-                             item.charge_cap / ROD_CHARGE_MULT);
-        _record_item_stat(cur_lev, itype, "RodRecharge", item.rod_plus);
-        break;
     case ITEM_MISCELLANY:
         all_plus_f = "MiscPlus";
         break;
@@ -858,8 +841,6 @@ static void _write_stat(map<string, double> &stats, string field)
     if (field == "PileQuant")
         value = stats["Num"] / stats["NumPiles"];
     else if (field == "WandCharges"
-             || field == "RodMana"
-             || field == "RodRecharge"
              || field == "MiscPlus"
              || field == "MonsHD"
              || field == "MonsHP"
