@@ -3,14 +3,16 @@
  * @brief Functions used to print information about various game objects.
 **/
 
-#ifndef DESCRIBE_H
-#define DESCRIBE_H
+#pragma once
 
+#include <functional>
 #include <sstream>
 #include <string>
 
+#include "command-type.h"
 #include "enum.h"
 #include "mon-util.h"
+#include "trap-type.h"
 
 struct monster_info;
 
@@ -58,7 +60,7 @@ void get_monster_db_desc(const monster_info &mi, describe_info &inf,
                          bool &has_stat_desc, bool force_seen = false);
 string serpent_of_hell_flavour(monster_type m);
 
-string player_spell_desc(spell_type spell, const item_def* item = nullptr);
+string player_spell_desc(spell_type spell);
 void get_spell_desc(const spell_type spell, describe_info &inf);
 void describe_spell(spell_type spelled,
                     const monster_info *mon_owner = nullptr,
@@ -117,5 +119,3 @@ protected:
     int h;
     ostringstream ostr;
 };
-
-#endif
