@@ -12,14 +12,14 @@
 #include "dgn-height.h"
 #include "dungeon.h"
 #include "english.h"
-#include "flood_find.h"
-#include "itemprop.h"
+#include "flood-find.h"
+#include "item-prop.h"
 #include "items.h"
 #include "libutil.h"
 #include "mapmark.h"
 #include "maps.h"
 #include "message.h"
-#include "mgen_data.h"
+#include "mgen-data.h"
 #include "mon-place.h"
 #include "state.h"
 #include "stringutil.h"
