@@ -16,10 +16,10 @@
 #include "database.h"
 #include "describe.h"
 #include "dungeon.h"
-#include "godpassive.h"
+#include "god-passive.h"
 #include "hints.h"
 #include "invent.h"
-#include "itemprop.h"
+#include "item-prop.h"
 #include "los.h"
 #include "macro.h"
 #include "message.h"
