@@ -40,16 +40,18 @@
 #include "end.h"
 #include "errors.h"
 #include "fineff.h"
+#include "food.h" //for HUNGER_MAXIMUM
 #include "ghost.h"
-#include "godabil.h"
-#include "godconduct.h" // for fedhas_rot_all_corpses
-#include "godcompanions.h"
-#include "godpassive.h"
+#include "god-abil.h"
+#include "god-conduct.h" // for fedhas_rot_all_corpses
+#include "god-companions.h"
+#include "god-passive.h"
 #include "hints.h"
 #include "initfile.h"
 #include "items.h"
 #include "jobs.h"
 #include "kills.h"
+#include "level-state-type.h"
 #include "libutil.h"
 #include "macro.h"
 #include "mapmark.h"
@@ -61,6 +63,7 @@
 #include "output.h"
 #include "place.h"
 #include "prompt.h"
+#include "species.h"
 #include "spl-summoning.h"
 #include "stash.h"  // for fedhas_rot_all_corpses
 #include "state.h"
@@ -74,7 +77,7 @@
  #include "tilepick-p.h"
 #endif
 #include "tileview.h"
-#include "timed_effects.h"
+#include "timed-effects.h"
 #include "unwind.h"
 #include "version.h"
 #include "view.h"
@@ -96,6 +99,8 @@ static bool _restore_tagged_chunk(package *save, const string &name,
                                   tag_type tag, const char* complaint);
 static bool _read_char_chunk(package *save);
 
+static bool _convert_obsolete_species();
+
 const short GHOST_SIGNATURE = short(0xDC55);
 
 const int GHOST_LIMIT = 27; // max number of ghost files per level
@@ -836,7 +841,8 @@ static int _get_dest_stair_type(branch_type old_branch,
 }
 
 static void _place_player_on_stair(branch_type old_branch,
-                                   int stair_taken, const coord_def& dest_pos)
+                                   int stair_taken, const coord_def& dest_pos,
+                                   const string &hatch_name)
 
 {
     bool find_first = true;
@@ -845,7 +851,8 @@ static void _place_player_on_stair(branch_type old_branch,
                                  static_cast<dungeon_feature_type>(stair_taken),
                                  find_first));
 
-    you.moveto(dgn_find_nearby_stair(stair_type, dest_pos, find_first));
+    you.moveto(dgn_find_nearby_stair(stair_type, dest_pos, find_first,
+                                     hatch_name));
 }
 
 static void _clear_env_map()
@@ -1028,8 +1035,9 @@ static void _do_lost_items()
 static void _fedhas_rot_all_corpses(const level_id& old_level)
 {
     bool messaged = false;
-    for (auto &item : mitm)
+    for (size_t mitm_index = 0; mitm_index < mitm.size(); ++mitm_index)
     {
+        item_def &item = mitm[mitm_index];
         if (!item.defined()
             || !item.is_type(OBJ_CORPSES, CORPSE_BODY)
             || item.props.exists(CORPSE_NEVER_DECAYS))
@@ -1037,7 +1045,13 @@ static void _fedhas_rot_all_corpses(const level_id& old_level)
             continue;
         }
 
-        turn_corpse_into_skeleton(item);
+        if (mons_skeleton(item.mon_type))
+            ASSERT(turn_corpse_into_skeleton(item));
+        else
+        {
+            item_was_destroyed(item);
+            destroy_item(mitm_index);
+        }
 
         if (!messaged)
         {
@@ -1185,14 +1199,14 @@ static void _make_level(dungeon_feature_type stair_taken,
  */
 static void _place_player(dungeon_feature_type stair_taken,
                           branch_type old_branch, const coord_def &return_pos,
-                          const coord_def &dest_pos)
+                          const coord_def &dest_pos, const string &hatch_name)
 {
     if (player_in_branch(BRANCH_ABYSS))
         you.moveto(ABYSS_CENTRE);
     else if (!return_pos.origin())
         you.moveto(return_pos);
     else
-        _place_player_on_stair(old_branch, stair_taken, dest_pos);
+        _place_player_on_stair(old_branch, stair_taken, dest_pos, hatch_name);
 
     // Don't return the player into walls, deep water, or a trap.
     for (distance_iterator di(you.pos(), true, false); di; ++di)
@@ -1220,7 +1234,7 @@ static void _place_player(dungeon_feature_type stair_taken,
 
         dprf("%s under player and can't be moved anywhere; killing",
              mon->name(DESC_PLAIN).c_str());
-        monster_die(mon, KILL_DISMISSED, NON_MONSTER);
+        monster_die(*mon, KILL_DISMISSED, NON_MONSTER);
         // XXX: do we need special handling for uniques...?
     }
 }
@@ -1231,6 +1245,22 @@ void trackers_init_new_level(bool transit)
     travel_init_new_level();
 }
 
+static string _get_hatch_name()
+{
+    vector <map_marker *> markers;
+    markers = find_markers_by_prop(HATCH_NAME_PROP);
+    for (auto m : markers)
+    {
+        if (m->pos == you.pos())
+        {
+            string name = m->property(HATCH_NAME_PROP);
+            ASSERT(!name.empty());
+            return name;
+        }
+    }
+    return "";
+}
+
 /**
  * Load the current level.
  *
@@ -1242,7 +1272,7 @@ bool load_level(dungeon_feature_type stair_taken, load_mode_type load_mode,
                 const level_id& old_level)
 {
 
-    string level_name = level_id::current().describe();
+    const string level_name = level_id::current().describe();
     const bool make_changes =
     (load_mode == LOAD_START_GAME || load_mode == LOAD_ENTER_LEVEL);
 
@@ -1250,6 +1280,11 @@ bool load_level(dungeon_feature_type stair_taken, load_mode_type load_mode,
     bool popped = false;
 
     coord_def return_pos; //TODO: initialize to null
+
+    string hatch_name = "";
+    if (feat_is_escape_hatch(stair_taken))
+        hatch_name = _get_hatch_name();
+
     if (load_mode != LOAD_VISITOR)
         popped = _leave_level(stair_taken, old_level, &return_pos);
 
@@ -1355,7 +1390,8 @@ bool load_level(dungeon_feature_type stair_taken, load_mode_type load_mode,
     {
         delete_all_clouds();
 
-        _place_player(stair_taken, old_level.branch, return_pos, dest_pos);
+        _place_player(stair_taken, old_level.branch, return_pos, dest_pos,
+                      hatch_name);
     }
 
     crawl_view.set_player_at(you.pos(), load_mode != LOAD_VISITOR);
@@ -1366,10 +1402,7 @@ bool load_level(dungeon_feature_type stair_taken, load_mode_type load_mode,
 
     // Load monsters in transit.
     if (load_mode == LOAD_ENTER_LEVEL)
-    {
         place_transiting_monsters();
-        place_transiting_items();
-    }
 
     if (make_changes)
     {
@@ -1873,6 +1906,15 @@ static bool _restore_game(const string& filename)
     if (Options.no_save)
         return false;
 
+#ifdef USE_TILE_WEB
+    // a more before the player is loaded will crash when it tries to send
+    // enough information to the webtiles client to render the display.
+    // TODO: is there a good way to do any mores in load_messages?
+    unwind_bool save_more(crawl_state.show_more_prompt, false);
+#endif
+
+    clear_message_store();
+
     you.save = new package((_get_savefile_directory() + filename).c_str(), true);
 
     if (!_read_char_chunk(you.save))
@@ -1910,6 +1952,8 @@ static bool _restore_game(const string& filename)
 
     _restore_tagged_chunk(you.save, "you", TAG_YOU, "Save data is invalid.");
 
+    _convert_obsolete_species();
+
     const int minorVersion = crawl_state.minor_version;
 
     if (you.save->has_chunk(CHUNK("st", "stashes")))
@@ -2084,6 +2128,52 @@ bool get_save_version(reader &file, int &major, int &minor)
     return true;
 }
 
+static bool _convert_obsolete_species()
+{
+    // At this point the character has been loaded but not resaved, but the grid, lua, stashes, etc have not been.
+#if TAG_MAJOR_VERSION == 34
+    if (you.species == SP_LAVA_ORC)
+    {
+        if (!yes_or_no("This <red>Lava Orc</red> save game cannot be loaded as-is. If you "
+                       "load it now, your character will be converted to a Hill Orc. Continue?"))
+        {
+            you.save->abort(); // don't even rewrite the header
+            delete you.save;
+            you.save = 0;
+            end(0, false, "Please load the save in an earlier version if you want to keep it as a Lava Orc.\n");
+        }
+        change_species_to(SP_HILL_ORC);
+        // No need for conservation
+        you.innate_mutation[MUT_CONSERVE_SCROLLS] = you.mutation[MUT_CONSERVE_SCROLLS] = 0;
+        // This is not an elegant way to deal with lava, but at this point the
+        // level isn't loaded so we can't check the grid features. In
+        // addition, even if the player isn't over lava, they might still get
+        // trapped.
+        fly_player(100);
+        return true;
+    }
+    if (you.species == SP_DJINNI)
+    {
+        if (!yes_or_no("This <red>Djinni</red> save game cannot be loaded as-is. If you "
+                       "load it now, your character will be converted to a Vine Stalker. Continue?"))
+        {
+            you.save->abort(); // don't even rewrite the header
+            delete you.save;
+            you.save = 0;
+            end(0, false, "Please load the save in an earlier version if you want to keep it as a Djinni.\n");
+        }
+        change_species_to(SP_VINE_STALKER);
+        you.magic_contamination = 0;
+        // Djinni were flying, so give the player some time to land
+        fly_player(100);
+        // Give them some time to find food. Creating food isn't safe as the grid doesn't exist yet, and may have water anyways.
+        you.hunger = HUNGER_MAXIMUM;
+        return true;
+    }
+#endif
+    return false;
+}
+
 static bool _read_char_chunk(package *save)
 {
     reader inf(save, "chr");
