@@ -3,8 +3,7 @@
  * @brief System independent functions
 **/
 
-#ifndef LIBUTIL_H
-#define LIBUTIL_H
+#pragma once
 
 #include <cctype>
 #include <map>
@@ -81,10 +80,6 @@ description_level_type description_type_by_name(const char *desc);
 
 bool shell_safe(const char *file);
 
-#ifdef USE_SOUND
-void play_sound(const char *file);
-#endif
-
 string unwrap_desc(string desc);
 
 /** Ignore any number of arguments and return true.
@@ -299,4 +294,3 @@ private:
 
 void init_signals();
 void release_cli_signals();
-#endif
