@@ -1,5 +1,4 @@
-#ifndef LIBW32C_H
-#define LIBW32C_H
+#pragma once
 
 #ifndef USE_TILE
 
@@ -9,5 +8,3 @@ static inline constexpr bool is_tiles() { return false; }
 void w32_insert_escape();
 
 #endif
-
-#endif
