@@ -3,12 +3,13 @@
  * @brief Crude macro-capability
 **/
 
-#ifndef MACRO_H
-#define MACRO_H
+#pragma once
 
 #include <deque>
 
+#include "command-type.h"
 #include "enum.h"
+#include "KeymapContext.h"
 
 class key_recorder;
 typedef deque<int> keyseq;
@@ -100,4 +101,3 @@ void insert_commands(string &desc, vector<command_type> cmds,
 
 // Let rc files declare macros:
 string read_rc_file_macro(const string& field);
-#endif
