@@ -3,10 +3,10 @@
  * @brief Misc functions.
 **/
 
-#ifndef MISC_H
-#define MISC_H
+#pragma once
 
 #include "coord.h"
+#include "maybe-bool.h"
 
 #include <algorithm>
 #include <chrono>
@@ -37,4 +37,3 @@ struct counted_monster_list
     string describe(description_level_type desc = DESC_THE,
                     bool force_article = false);
 };
-#endif
