@@ -16,8 +16,9 @@
 #include "dgn-overview.h"
 #include "dungeon.h"
 #include "exclude.h"
+#include "god-passive.h"
 #include "hints.h"
-#include "itemprop.h"
+#include "item-prop.h"
 #include "losglobal.h"
 #include "macro.h"
 #include "message.h"
@@ -105,7 +106,7 @@ static bool _mon_tries_regain_los(monster* mon)
 // to ideal_range (too far = easier to escape, too close = easier to ambush).
 static void _set_firing_pos(monster* mon, coord_def target)
 {
-    const int ideal_range = LOS_RADIUS / 2;
+    const int ideal_range = LOS_DEFAULT_RANGE / 2;
     const int current_distance = mon->pos().distance_from(target);
 
     // We don't consider getting farther away unless already very close.
@@ -700,7 +701,7 @@ void handle_behaviour(monster* mon)
             }
 
             if (mon->strict_neutral() && mons_is_slime(*mon)
-                && you_worship(GOD_JIYVA))
+                && have_passive(passive_t::neutral_slimes))
             {
                 set_random_slime_target(mon);
             }
@@ -840,7 +841,8 @@ void handle_behaviour(monster* mon)
                     stop_retreat = true;
 
             }
-            else if (grid_distance(mon->pos(), you.pos()) > LOS_RADIUS + 2)
+            else if (grid_distance(mon->pos(), you.pos()) >
+                     LOS_DEFAULT_RANGE + 2)
             {
                 // We're too far from the player. Idle around and wait for
                 // them to catch up.
@@ -864,7 +866,7 @@ void handle_behaviour(monster* mon)
                 // idling (to prevent it from repeatedly resetting idle
                 // time if its own wanderings bring it closer to the player)
                 if (mon->props.exists("idle_point")
-                    && grid_distance(mon->pos(), you.pos()) < LOS_RADIUS)
+                    && grid_distance(mon->pos(), you.pos()) < LOS_DEFAULT_RANGE)
                 {
                     mon->props.erase("idle_point");
                     mon->props.erase("idle_deadline");
@@ -1074,6 +1076,9 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
         if (mon->has_ench(ENCH_GOLD_LUST))
             mon->del_ench(ENCH_GOLD_LUST);
 
+        if (mon->has_ench(ENCH_DISTRACTED_ACROBATICS))
+            mon->del_ench(ENCH_DISTRACTED_ACROBATICS);
+
         // Will turn monster against <src>.
         // Orders to withdraw take precedence over interruptions
         if (mon->behaviour == BEH_WITHDRAW && src != &you)
@@ -1457,7 +1462,7 @@ void make_mons_leave_level(monster* mon)
         // Pacified monsters leaving the level take their stuff with
         // them.
         mon->flags |= MF_HARD_RESET;
-        monster_die(mon, KILL_DISMISSED, NON_MONSTER);
+        monster_die(*mon, KILL_DISMISSED, NON_MONSTER);
     }
 }
 
