@@ -379,7 +379,7 @@ static const mon_spellbook mspell_list[] =
     },
 
     // ('m') Merfolk and friends.
-    {  MST_SIREN,
+    {  MST_MERFOLK_SIREN,
       {
        { SPELL_SIREN_SONG, 160, MON_SPELL_WIZARD },
       }
@@ -632,10 +632,11 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_DRACONIAN_CALLER,
+    {  MST_DRACONIAN_STORMCALLER,
       {
-       { SPELL_SUMMON_DRAKES, 55, MON_SPELL_WIZARD },
-       { SPELL_SUMMON_DRAGON, 10, MON_SPELL_WIZARD },
+        { SPELL_SMITING, 20, MON_SPELL_PRIEST },
+        { SPELL_SUMMON_DRAKES, 20, MON_SPELL_PRIEST },
+        { SPELL_UPHEAVAL, 20, MON_SPELL_PRIEST },
       }
     },
 
@@ -649,15 +650,6 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_DRACONIAN_ZEALOT,
-      {
-       { SPELL_CALL_DOWN_DAMNATION, 11, MON_SPELL_PRIEST },
-       { SPELL_SMITING, 11, MON_SPELL_PRIEST },
-       { SPELL_SUMMON_DEMON, 11, MON_SPELL_PRIEST },
-       { SPELL_MINOR_HEALING, 22, MON_SPELL_PRIEST },
-      }
-    },
-
     // ('s') Spiders and insects.
     {  MST_JUMPING_SPIDER,
       {
@@ -844,9 +836,9 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_MOTTLED_DRAGON,
+    {  MST_ACID_DRAGON,
       {
-       { SPELL_STICKY_FLAME_RANGE, 55, MON_SPELL_NATURAL | MON_SPELL_BREATH
+       { SPELL_SPIT_ACID, 55, MON_SPELL_NATURAL | MON_SPELL_BREATH
                                         | MON_SPELL_NOISY },
       }
     },
@@ -1575,7 +1567,7 @@ static const mon_spellbook mspell_list[] =
     // ('8') Animate / statues.
     {  MST_USHABTI,
       {
-       { SPELL_DEATH_RATTLE, 57, MON_SPELL_MAGICAL },
+       { SPELL_DEATH_RATTLE, 36, MON_SPELL_MAGICAL },
        { SPELL_WARNING_CRY, 56, MON_SPELL_NATURAL | MON_SPELL_NO_SILENT
                                 | MON_SPELL_BREATH },
        { SPELL_DISPEL_UNDEAD, 44, MON_SPELL_MAGICAL },
@@ -1814,6 +1806,7 @@ static const mon_spellbook mspell_list[] =
     { MST_BAI_SUZHEN_DRAGON,
       {
         { SPELL_PRIMAL_WAVE, 60, MON_SPELL_NATURAL | MON_SPELL_BREATH },
+        { SPELL_RING_OF_THUNDER, 100, MON_SPELL_NATURAL | MON_SPELL_INSTANT },
       }
     },
 
