@@ -13,8 +13,8 @@
 #include "coordit.h"
 #include "dactions.h"
 #include "dungeon.h"
-#include "godcompanions.h"
-#include "godpassive.h" // passive_t::convert_orcs
+#include "god-companions.h"
+#include "god-passive.h" // passive_t::convert_orcs
 #include "items.h"
 #include "libutil.h" // map_find
 #include "mon-place.h"
@@ -23,18 +23,8 @@
 #define MAX_LOST 100
 
 monsters_in_transit the_lost_ones;
-items_in_transit    transiting_items;
 
-void transit_lists_clear()
-{
-    the_lost_ones.clear();
-    transiting_items.clear();
-}
-
-static void level_place_lost_monsters(m_transit_list &m);
-static void level_place_followers(m_transit_list &m);
-
-static void cull_lost_mons(m_transit_list &mlist, int how_many)
+static void _cull_lost_mons(m_transit_list &mlist, int how_many)
 {
     // First pass, drop non-uniques.
     for (auto i = mlist.begin(); i != mlist.end();)
@@ -55,58 +45,21 @@ static void cull_lost_mons(m_transit_list &mlist, int how_many)
         mlist.erase(mlist.begin());
 }
 
-static void cull_lost_items(i_transit_list &ilist, int how_many)
-{
-    // First pass, drop non-artefacts.
-    for (auto i = ilist.begin(); i != ilist.end();)
-    {
-        auto finger = i++;
-        if (!is_artefact(*finger))
-        {
-            ilist.erase(finger);
-
-            if (--how_many <= MAX_LOST)
-                return;
-        }
-    }
-
-    // Second pass, drop randarts.
-    for (auto i = ilist.begin(); i != ilist.end();)
-    {
-        auto finger = i++;
-        if (is_random_artefact(*finger))
-        {
-            ilist.erase(finger);
-
-            if (--how_many <= MAX_LOST)
-                return;
-        }
-    }
-
-    // Third pass, drop unrandarts.
-    for (auto i = ilist.begin(); i != ilist.end();)
-    {
-        auto finger = i++;
-        if (is_unrandom_artefact(*finger))
-        {
-            ilist.erase(finger);
-
-            if (--how_many <= MAX_LOST)
-                return;
-        }
-    }
-
-    // If we're still over the limit (unlikely), just lose
-    // the old ones.
-    while (how_many-- > MAX_LOST && !ilist.empty())
-        ilist.erase(ilist.begin());
-}
-
+/**
+ * Get the monster transit list for the given level.
+ * @param lid    The level.
+ * @returns      The monster transit list.
+ **/
 m_transit_list *get_transit_list(const level_id &lid)
 {
     return map_find(the_lost_ones, lid);
 }
 
+/**
+ * Add a monster to a level's transit list.
+ * @param lid    The level.
+ * @param m      The monster to add.
+ **/
 void add_monster_to_transit(const level_id &lid, const monster& m)
 {
     ASSERT(m.alive());
@@ -122,9 +75,14 @@ void add_monster_to_transit(const level_id &lid, const monster& m)
 
     const int how_many = mlist.size();
     if (how_many > MAX_LOST)
-        cull_lost_mons(mlist, how_many);
+        _cull_lost_mons(mlist, how_many);
 }
 
+/**
+ * Remove a monster from a level's transit list.
+ * @param lid    The level.
+ * @param mid    The mid_t of the monster to remove.
+ **/
 void remove_monster_from_transit(const level_id &lid, mid_t mid)
 {
     m_transit_list &mlist = the_lost_ones[lid];
@@ -139,6 +97,28 @@ void remove_monster_from_transit(const level_id &lid, mid_t mid)
     }
 }
 
+static void _level_place_followers(m_transit_list &m)
+{
+    for (auto i = m.begin(); i != m.end();)
+    {
+        auto mon = i++;
+        if ((mon->mons.flags & MF_TAKING_STAIRS) && mon->place(true))
+        {
+            if (mon->mons.is_divine_companion())
+            {
+                move_companion_to(monster_by_mid(mon->mons.mid),
+                                                 level_id::current());
+            }
+
+            // Now that the monster is onlevel, we can safely apply traps to it.
+            if (monster* new_mon = monster_by_mid(mon->mons.mid))
+                // old loc isn't really meaningful
+                new_mon->apply_location_effects(new_mon->pos());
+            m.erase(mon);
+        }
+    }
+}
+
 static void _place_lost_ones(void (*placefn)(m_transit_list &ml))
 {
     level_id c = level_id::current();
@@ -151,23 +131,21 @@ static void _place_lost_ones(void (*placefn)(m_transit_list &ml))
         the_lost_ones.erase(i);
 }
 
-void place_transiting_monsters()
-{
-    _place_lost_ones(level_place_lost_monsters);
-}
-
+/**
+ * Place any followers transiting to this level.
+ **/
 void place_followers()
 {
-    _place_lost_ones(level_place_followers);
+    _place_lost_ones(_level_place_followers);
 }
 
-static bool place_lost_monster(follower &f)
+static bool _place_lost_monster(follower &f)
 {
     dprf("Placing lost one: %s", f.mons.name(DESC_PLAIN, true).c_str());
     return f.place(false);
 }
 
-static void level_place_lost_monsters(m_transit_list &m)
+static void _level_place_lost_monsters(m_transit_list &m)
 {
     for (auto i = m.begin(); i != m.end(); )
     {
@@ -178,9 +156,10 @@ static void level_place_lost_monsters(m_transit_list &m)
         if (player_in_branch(BRANCH_ABYSS) && coinflip())
             continue;
 
-        if (place_lost_monster(*mon))
+        if (_place_lost_monster(*mon))
         {
-            // Now that the monster is onlevel, we can safely apply traps to it.
+            // Now that the monster is on the level, we can safely apply traps
+            // to it.
             if (monster* new_mon = monster_by_mid(mon->mons.mid))
                 // old loc isn't really meaningful
                 new_mon->apply_location_effects(new_mon->pos());
@@ -189,63 +168,12 @@ static void level_place_lost_monsters(m_transit_list &m)
     }
 }
 
-static void level_place_followers(m_transit_list &m)
+/**
+ * Place any monsters in transit to this level.
+ **/
+void place_transiting_monsters()
 {
-    for (auto i = m.begin(); i != m.end();)
-    {
-        auto mon = i++;
-        if ((mon->mons.flags & MF_TAKING_STAIRS) && mon->place(true))
-        {
-            if (mon->mons.is_divine_companion())
-                move_companion_to(monster_by_mid(mon->mons.mid), level_id::current());
-            // Now that the monster is onlevel, we can safely apply traps to it.
-            if (monster* new_mon = monster_by_mid(mon->mons.mid))
-                // old loc isn't really meaningful
-                new_mon->apply_location_effects(new_mon->pos());
-            m.erase(mon);
-        }
-    }
-}
-
-void add_item_to_transit(const level_id &lid, const item_def &i)
-{
-    i_transit_list &ilist = transiting_items[lid];
-    ilist.push_back(i);
-
-    dprf("Item in transit: %s", i.name(DESC_PLAIN).c_str());
-
-    const int how_many = ilist.size();
-    if (how_many > MAX_LOST)
-        cull_lost_items(ilist, how_many);
-}
-
-void place_transiting_items()
-{
-    level_id c = level_id::current();
-
-    i_transit_list *transit = map_find(transiting_items, c);
-    if (!transit)
-        return;
-
-    i_transit_list keep;
-    for (item_def &item : *transit)
-    {
-        coord_def pos = item.pos;
-
-        if (!in_bounds(pos))
-            pos = random_in_bounds();
-
-        const coord_def where_to_go =
-            dgn_find_nearby_stair(DNGN_ESCAPE_HATCH_DOWN,
-                                  pos, true);
-
-        // List of items we couldn't place.
-        if (!copy_item_to_grid(item, where_to_go, -1, false, true))
-            keep.push_back(item);
-    }
-
-    // Only unplaceable items are kept in list.
-    *transit = keep;
+    _place_lost_ones(_level_place_lost_monsters);
 }
 
 void apply_daction_to_transit(daction_type act)
@@ -349,63 +277,71 @@ void follower::restore_mons_items(monster& m)
     }
 }
 
-static bool _is_religious_follower(const monster* mon)
+static bool _is_religious_follower(const monster &mon)
 {
     return (you_worship(GOD_YREDELEMNUL)
             || will_have_passive(passive_t::convert_orcs)
             || you_worship(GOD_FEDHAS))
-                && is_follower(*mon);
+                && is_follower(mon);
 }
 
-static bool _tag_follower_at(const coord_def &pos, bool &real_follower)
+static bool _mons_can_follow_player_from(const monster &mons,
+                                         const coord_def from,
+                                         bool within_level = false)
 {
-    if (!in_bounds(pos) || pos == you.pos())
+    if (!mons.alive()
+        || mons.speed_increment < 50
+        || mons.incapacitated()
+        || mons.is_stationary())
+    {
+        return false;
+    }
+
+    if (!monster_habitable_grid(&mons, DNGN_FLOOR))
+        return false;
+
+    // Only non-wandering friendly monsters or those actively
+    // seeking the player will follow up/down stairs.
+    if (!mons.friendly()
+          && (!mons_is_seeking(mons) || mons.foe != MHITYOU)
+        || mons.foe == MHITNOT)
+    {
+        return false;
+    }
+
+    // Unfriendly monsters must be directly adjacent to follow.
+    if (!mons.friendly() && (mons.pos() - from).rdist() > 1)
+        return false;
+
+    // Monsters that can't use stairs can still be marked as followers
+    // (though they'll be ignored for transit), so any adjacent real
+    // follower can follow through. (jpeg)
+    if (within_level && !mons_class_can_use_transporter(mons.type)
+        || !within_level && !mons_can_use_stairs(mons, grd(from)))
+    {
+        if (_is_religious_follower(mons))
+            return true;
+
+        return false;
+    }
+    return true;
+}
+
+// Tag any monster following the player
+static bool _tag_follower_at(const coord_def &pos, const coord_def &from,
+                             bool &real_follower)
+{
+    if (!in_bounds(pos) || pos == from)
         return false;
 
     monster* fol = monster_at(pos);
     if (fol == nullptr)
         return false;
 
-    if (!fol->alive()
-        || fol->speed_increment < 50
-        || fol->incapacitated()
-        || fol->is_stationary())
-    {
+    if (!_mons_can_follow_player_from(*fol, from))
         return false;
-    }
-
-    if (!monster_habitable_grid(fol, DNGN_FLOOR))
-        return false;
-
-    // Only non-wandering friendly monsters or those actively
-    // seeking the player will follow up/down stairs.
-    if (!fol->friendly()
-          && (!mons_is_seeking(*fol) || fol->foe != MHITYOU)
-        || fol->foe == MHITNOT)
-    {
-        return false;
-    }
-
-    // Unfriendly monsters must be directly adjacent to follow.
-    if (!fol->friendly() && (pos - you.pos()).rdist() > 1)
-        return false;
-
-    // Monsters that can't use stairs can still be marked as followers
-    // (though they'll be ignored for transit), so any adjacent real
-    // follower can follow through. (jpeg)
-    if (!mons_can_use_stairs(*fol, grd(you.pos())))
-    {
-        if (_is_religious_follower(fol))
-        {
-            fol->flags |= MF_TAKING_STAIRS;
-            return true;
-        }
-        return false;
-    }
 
     real_follower = true;
-
-    // Monster is chasing player through stairs.
     fol->flags |= MF_TAKING_STAIRS;
 
     // Clear patrolling/travel markers.
@@ -415,17 +351,15 @@ static bool _tag_follower_at(const coord_def &pos, bool &real_follower)
 
     fol->clear_clinging();
 
-    dprf("%s is marked for following.",
-         fol->name(DESC_THE, true).c_str());
-
+    dprf("%s is marked for following.", fol->name(DESC_THE, true).c_str());
     return true;
 }
 
-static int follower_tag_radius()
+static int _follower_tag_radius(const coord_def &from)
 {
     // If only friendlies are adjacent, we set a max radius of 5, otherwise
     // only adjacent friendlies may follow.
-    for (adjacent_iterator ai(you.pos()); ai; ++ai)
+    for (adjacent_iterator ai(from); ai; ++ai)
     {
         if (const monster* mon = monster_at(*ai))
             if (!mon->friendly())
@@ -435,15 +369,27 @@ static int follower_tag_radius()
     return 5;
 }
 
-void tag_followers()
+/**
+ * Handle movement of adjacent player followers from a given location. This is
+ * used when traveling through stairs or a transporter.
+ *
+ * @param from       The location from which the player moved.
+ * @param handler    A handler function that does movement of the actor to the
+ *                   destination, returning true if the actor was friendly. The
+ *                   `real` argument tracks whether the actor was an actual
+ *                   follower that counts towards the follower limit.
+ **/
+void handle_followers(const coord_def &from,
+                      bool (*handler)(const coord_def &pos,
+                                      const coord_def &from, bool &real))
 {
-    const int radius = follower_tag_radius();
+    const int radius = _follower_tag_radius(from);
     int n_followers = 18;
 
     vector<coord_def> places[2];
     int place_set = 0;
 
-    places[place_set].push_back(you.pos());
+    places[place_set].push_back(from);
     memset(travel_point_distance, 0, sizeof(travel_distance_grid_t));
     while (!places[place_set].empty())
     {
@@ -451,7 +397,7 @@ void tag_followers()
         {
             for (adjacent_iterator ai(p); ai; ++ai)
             {
-                if ((*ai - you.pos()).rdist() > radius
+                if ((*ai - from).rdist() > radius
                     || travel_point_distance[ai->x][ai->y])
                 {
                     continue;
@@ -459,7 +405,7 @@ void tag_followers()
                 travel_point_distance[ai->x][ai->y] = 1;
 
                 bool real_follower = false;
-                if (_tag_follower_at(*ai, real_follower))
+                if (handler(*ai, from, real_follower))
                 {
                     // If we've run out of our follower allowance, bail.
                     if (real_follower && --n_followers <= 0)
@@ -473,8 +419,52 @@ void tag_followers()
     }
 }
 
+/**
+ * Tag all followers at your position for level transit through stairs.
+ **/
+void tag_followers()
+{
+    handle_followers(you.pos(), _tag_follower_at);
+}
+
+/**
+ * Untag all followers at your position for level transit through stairs.
+ **/
 void untag_followers()
 {
     for (auto &mons : menv_real)
         mons.flags &= ~MF_TAKING_STAIRS;
 }
+
+static bool _transport_follower_at(const coord_def &pos, const coord_def &from,
+                                   bool &real_follower)
+{
+    if (!in_bounds(pos) || pos == from)
+        return false;
+
+    monster* fol = monster_at(pos);
+    if (fol == nullptr)
+        return false;
+
+    if (!_mons_can_follow_player_from(*fol, from, true))
+        return false;
+
+    if (fol->find_place_to_live(true))
+    {
+        real_follower = true;
+        env.map_knowledge(pos).clear_monster();
+        dprf("%s is transported.", fol->name(DESC_THE, true).c_str());
+    }
+
+    return true;
+}
+
+/**
+ * Transport all followers from a position to a position near your current one.
+ *
+ * @param from    The position from where you transported.
+ **/
+void transport_followers_from(const coord_def &from)
+{
+    handle_followers(from, _transport_follower_at);
+}
