@@ -368,6 +368,12 @@ mutation_activity_type mutation_activity_level(mutation_type mut)
     if (you.form == transformation::blade_hands && mut == MUT_PAWS)
         return mutation_activity_type::INACTIVE;
 
+    if (you.form == transformation::tree
+        && (mut == MUT_BLINK || mut == MUT_TELEPORT))
+    {
+        return mutation_activity_type::INACTIVE;
+    }
+
     if (you_worship(GOD_DITHMENOS) && mut == MUT_IGNITE_BLOOD)
         return mutation_activity_type::INACTIVE;
 
@@ -714,7 +720,7 @@ string describe_mutations(bool center_title)
     if (have_passive(passive_t::frail)
         || player_under_penance(GOD_HEPLIAKLQANA))
     {
-        result += "<lightred>Your life essence is reduced. (-10% HP)"
+        result += "<lightred>Your life essence is reduced to manifest your ancestor. (-10% HP)"
                   "</lightred>\n";
     }
 
@@ -2066,14 +2072,15 @@ mutation_type mutation_from_name(string name, bool allow_category, vector<mutati
         for (int i = CATEGORY_MUTATIONS; i < MUT_NON_MUTATION; ++i)
         {
             mutation_type mut = static_cast<mutation_type>(i);
-            const char* mut_name = category_mutation_name(mut);
-            if (!mut_name)
+            const char* mut_name_c = category_mutation_name(mut);
+            if (!mut_name_c)
                 continue;
+            const string mut_name = lowercase_string(mut_name_c);
 
             if (spec == mut_name)
                 return mut; // note, won't fully populate partial_matches
 
-            if (partial_matches && strstr(mut_name, spec.c_str()))
+            if (partial_matches && strstr(mut_name.c_str(), spec.c_str()))
                 partial_matches->push_back(mut);
         }
     }
@@ -2081,9 +2088,10 @@ mutation_type mutation_from_name(string name, bool allow_category, vector<mutati
     for (int i = 0; i < NUM_MUTATIONS; ++i)
     {
         mutation_type mut = static_cast<mutation_type>(i);
-        const char* mut_name = mutation_name(mut);
-        if (!mut_name)
+        const char *mut_name_c = mutation_name(mut);
+        if (!mut_name_c)
             continue;
+        const string mut_name = lowercase_string(mut_name_c);
 
         if (spec == mut_name)
         {
@@ -2091,7 +2099,7 @@ mutation_type mutation_from_name(string name, bool allow_category, vector<mutati
             break;
         }
 
-        if (partial_matches && strstr(mut_name, spec.c_str()))
+        if (partial_matches && strstr(mut_name.c_str(), spec.c_str()))
             partial_matches->push_back(mut);
     }
 
