@@ -241,7 +241,11 @@ static void _resolve_species(newgame_def& ng, const newgame_def& ng_choice)
     case SP_RANDOM:
         // any valid species will do
         if (ng.job == JOB_UNKNOWN)
-            ng.species = RANDOM_ELEMENT(species_order);
+        {
+            do {
+                ng.species = RANDOM_ELEMENT(species_order);
+            } while (!is_starting_species(ng.species));
+        }
         else
         {
             // Pick a random legal character.
@@ -691,8 +695,8 @@ static void _add_choice_menu_options(int choice_type,
     tmp->set_fg_colour(BROWN);
     tmp->add_hotkey('+');
     // If the player has species chosen, use VIABLE, otherwise use RANDOM
-    if ((choice_type == C_SPECIES && ng.species != SP_UNKNOWN)
-       || (choice_type == C_JOB && ng.job != JOB_UNKNOWN))
+    if ((choice_type == C_SPECIES && ng.job != JOB_UNKNOWN)
+       || (choice_type == C_JOB && ng.species != SP_UNKNOWN))
     {
         tmp->set_id(M_VIABLE);
     }
