@@ -3,13 +3,14 @@
  * @brief Functions used to print player related info.
 **/
 
-#ifndef OUTPUT_H
-#define OUTPUT_H
+#pragma once
 
 #ifdef DGL_SIMPLE_MESSAGING
 void update_message_status();
 #endif
 
+void reset_hud();
+
 void update_turn_count();
 
 void print_stats();
@@ -26,6 +27,6 @@ int equip_name_to_slot(const char *s);
 
 void print_overview_screen();
 
-string dump_overview_screen(bool full_id);
+string mutation_overview();
 
-#endif
+string dump_overview_screen(bool full_id);
