@@ -58,26 +58,28 @@
 #include "fineff.h"
 #include "food.h"
 #include "fprop.h"
-#include "godabil.h"
-#include "godcompanions.h"
-#include "godconduct.h"
-#include "goditem.h"
-#include "godpassive.h"
-#include "godprayer.h"
+#include "god-abil.h"
+#include "god-companions.h"
+#include "god-conduct.h"
+#include "god-item.h"
+#include "god-passive.h"
+#include "god-prayer.h"
 #include "hints.h"
 #include "initfile.h"
 #include "invent.h"
-#include "itemname.h"
-#include "itemprop.h"
+#include "item-name.h"
+#include "item-prop.h"
 #include "items.h"
-#include "item_use.h"
+#include "item-status-flag-type.h"
+#include "item-use.h"
+#include "level-state-type.h"
 #include "libutil.h"
 #include "luaterp.h"
 #include "macro.h"
-#include "map_knowledge.h"
+#include "map-knowledge.h"
 #include "mapmark.h"
 #include "maps.h"
-#include "melee_attack.h"
+#include "melee-attack.h"
 #include "message.h"
 #include "misc.h"
 #include "mon-abil.h"
@@ -85,6 +87,7 @@
 #include "mon-cast.h"
 #include "mon-death.h"
 #include "mon-place.h"
+#include "mon-tentacle.h"
 #include "mon-util.h"
 #include "mutation.h"
 #include "options.h"
@@ -123,7 +126,7 @@
 #include "tiledef-dngn.h"
 #include "tilepick.h"
 #endif
-#include "timed_effects.h"
+#include "timed-effects.h"
 #include "transform.h"
 #include "traps.h"
 #include "travel.h"
@@ -294,7 +297,8 @@ static int _current_horror_level()
         if (mon == nullptr
             || mons_aligned(mon, &you)
             || !mons_is_threatening(*mon)
-            || !you.can_see(*mon))
+            || !you.can_see(*mon)
+            || mons_is_tentacle_or_tentacle_segment(mon->type))
         {
             continue;
         }
@@ -344,7 +348,7 @@ static void _end_horror()
  */
 static void _update_cowardice()
 {
-    if (!player_mutation_level(MUT_COWARDICE))
+    if (!you.has_mutation(MUT_COWARDICE))
     {
         // If the player somehow becomes sane again, handle that
         _end_horror();
@@ -461,8 +465,11 @@ void player_reacts_to_monsters()
 
     check_monster_detect();
 
-    if (have_passive(passive_t::detect_items) || you.mutation[MUT_JELLY_GROWTH])
+    if (have_passive(passive_t::detect_items) || you.has_mutation(MUT_JELLY_GROWTH)
+        || you.get_mutation_level(MUT_STRONG_NOSE) > 0)
+    {
         detect_items(-1);
+    }
 
     _decrement_paralysis(you.time_taken);
     _decrement_petrification(you.time_taken);
@@ -509,19 +516,17 @@ static void _handle_recitation(int step)
 
     if (step == 0)
     {
-        string speech = zin_recite_text(you.attribute[ATTR_RECITE_SEED],
-                                        you.attribute[ATTR_RECITE_TYPE], -1);
-        speech += ".";
-        if (one_chance_in(9))
+        ostringstream speech;
+        speech << zin_recite_text(you.attribute[ATTR_RECITE_SEED],
+                                  you.attribute[ATTR_RECITE_TYPE], -1);
+        speech << '.';
+        if (one_chance_in(27))
         {
             const string closure = getSpeakString("recite_closure");
-            if (!closure.empty() && one_chance_in(3))
-            {
-                speech += " ";
-                speech += closure;
-            }
+            if (!closure.empty())
+                speech << ' ' << closure;
         }
-        mprf(MSGCH_DURATION, "You finish reciting %s", speech.c_str());
+        mprf(MSGCH_DURATION, "You finish reciting %s", speech.str().c_str());
     }
 }
 
@@ -572,7 +577,7 @@ static void _decrement_durations()
     if (you.gourmand())
     {
         // Innate gourmand is always fully active.
-        if (player_mutation_level(MUT_GOURMAND) > 0)
+        if (you.has_mutation(MUT_GOURMAND))
             you.duration[DUR_GOURMAND] = GOURMAND_MAX;
         else if (you.duration[DUR_GOURMAND] < GOURMAND_MAX && coinflip())
             you.duration[DUR_GOURMAND] += delay;
@@ -602,39 +607,16 @@ static void _decrement_durations()
     if (you.duration[DUR_LIQUEFYING])
         invalidate_agrid();
 
-    if (you.duration[DUR_DIVINE_SHIELD] > 0)
-    {
-        if (you.duration[DUR_DIVINE_SHIELD] > 1)
-        {
-            you.duration[DUR_DIVINE_SHIELD] -= delay;
-            if (you.duration[DUR_DIVINE_SHIELD] <= 1)
-            {
-                you.duration[DUR_DIVINE_SHIELD] = 1;
-                mprf(MSGCH_DURATION, "Your divine shield starts to fade.");
-            }
-        }
-
-        if (you.duration[DUR_DIVINE_SHIELD] == 1 && !one_chance_in(3))
-        {
-            you.redraw_armour_class = true;
-            if (--you.attribute[ATTR_DIVINE_SHIELD] == 0)
-            {
-                you.duration[DUR_DIVINE_SHIELD] = 0;
-                mprf(MSGCH_DURATION, "Your divine shield fades away.");
-            }
-        }
-    }
-
     // FIXME: [ds] Remove this once we've ensured durations can never go < 0?
     if (you.duration[DUR_TRANSFORMATION] <= 0
-        && you.form != TRAN_NONE)
+        && you.form != transformation::none)
     {
         you.duration[DUR_TRANSFORMATION] = 1;
     }
 
     // Vampire bat transformations are permanent (until ended), unless they
     // are uncancellable (polymorph wand on a full vampire).
-    if (you.species != SP_VAMPIRE || you.form != TRAN_BAT
+    if (you.species != SP_VAMPIRE || you.form != transformation::bat
         || you.duration[DUR_TRANSFORMATION] <= 5 * BASELINE_DELAY
         || you.transform_uncancellable)
     {
@@ -684,7 +666,7 @@ static void _decrement_durations()
     dec_ambrosia_player(delay);
     dec_channel_player(delay);
     dec_slow_player(delay);
-    dec_exhaust_player(delay);
+    dec_berserk_recovery_player(delay);
     dec_haste_player(delay);
 
     if (you.duration[DUR_LIQUEFYING] && !you.stand_on_solid_ground())
@@ -820,7 +802,7 @@ static void _decrement_durations()
     }
 
     if (you.duration[DUR_GRASPING_ROOTS])
-        check_grasping_roots(&you);
+        check_grasping_roots(you);
 
     if (you.attribute[ATTR_NEXT_RECALL_INDEX] > 0)
         do_recall(delay);
@@ -853,6 +835,12 @@ static void _decrement_durations()
     else if (!sanguine_armour_is_valid && you.duration[DUR_SANGUINE_ARMOUR])
         you.duration[DUR_SANGUINE_ARMOUR] = 1; // expire
 
+    if (you.attribute[ATTR_HEAVENLY_STORM]
+        && !you.duration[DUR_HEAVENLY_STORM])
+    {
+        end_heavenly_storm(); // we shouldn't hit this, but just in case
+    }
+
     // these should be after decr_ambrosia, transforms, liquefying, etc.
     for (int i = 0; i < NUM_DURATIONS; ++i)
         if (duration_decrements_normally((duration_type) i))
@@ -935,6 +923,7 @@ static void _regenerate_hp_and_mp(int delay)
     if (crawl_state.disables[DIS_PLAYER_REGEN])
         return;
 
+    // HP Regeneration
     if (!you.duration[DUR_DEATHS_DOOR])
     {
         const int base_val = player_regen();
@@ -944,7 +933,7 @@ static void _regenerate_hp_and_mp(int delay)
     while (you.hit_points_regeneration >= 100)
     {
         // at low mp, "mana link" restores mp in place of hp
-        if (player_mutation_level(MUT_MANA_LINK)
+        if (you.has_mutation(MUT_MANA_LINK)
             && !x_chance_in_y(you.magic_points, you.max_magic_points))
         {
             inc_mp(1);
@@ -958,19 +947,14 @@ static void _regenerate_hp_and_mp(int delay)
 
     update_regen_amulet_attunement();
 
+    // MP Regeneration
     if (!player_regenerates_mp())
         return;
 
     if (you.magic_points < you.max_magic_points)
     {
-        const int base_val = 7 + you.max_magic_points / 2;
+        const int base_val = player_mp_regen();
         int mp_regen_countup = div_rand_round(base_val * delay, BASELINE_DELAY);
-
-        if (player_mutation_level(MUT_MANA_REGENERATION))
-            mp_regen_countup *= 2;
-        if (you.props[MANA_REGEN_AMULET_ACTIVE].get_int() == 1)
-            mp_regen_countup += div_rand_round(15 * delay, BASELINE_DELAY);
-
         you.magic_points_regeneration += mp_regen_countup;
     }
 
@@ -997,12 +981,7 @@ void player_reacts()
     mprf(MSGCH_DIAGNOSTICS, "stealth: %d", stealth);
 #endif
 
-#if TAG_MAJOR_VERSION == 34
-    if (you.species == SP_LAVA_ORC)
-        temperature_check();
-#endif
-
-    if (player_mutation_level(MUT_DEMONIC_GUARDIAN))
+    if (you.has_mutation(MUT_DEMONIC_GUARDIAN))
         check_demonic_guardian();
 
     _check_equipment_conducts();
@@ -1041,7 +1020,7 @@ void player_reacts()
             if (!crawl_state.disables[DIS_SAVE_CHECKPOINTS])
                 save_game(false);
         }
-        else if (you.form == TRAN_WISP && !you.stasis())
+        else if (you.form == transformation::wisp && !you.stasis())
             uncontrolled_blink();
     }
 
@@ -1087,8 +1066,6 @@ void player_reacts()
     if (you.duration[DUR_POISONING])
         handle_player_poison(you.time_taken);
 
-    recharge_rods(you.time_taken, false);
-
     // Reveal adjacent mimics.
     for (adjacent_iterator ai(you.pos(), false); ai; ++ai)
         discover_mimic(*ai);
