@@ -7,11 +7,14 @@
 
 #include "randbook.h"
 
+#include <functional>
+
 #include "artefact.h"
 #include "database.h"
 #include "english.h"
-#include "goditem.h"
-#include "itemname.h"
+#include "god-item.h"
+#include "item-name.h"
+#include "item-status-flag-type.h"
 #include "items.h"
 #include "religion.h"
 #include "spl-book.h"
@@ -38,8 +41,7 @@ spschool_flag_type random_book_theme()
 {
     vector<spschool_flag_type> disciplines;
     for (auto discipline : spschools_type::range())
-        if (!(discipline & SPTYP_DIVINATION))
-            disciplines.push_back(discipline);
+        disciplines.push_back(discipline);
     return disciplines[random2(disciplines.size())];
 }
 
@@ -953,7 +955,7 @@ static string _gen_randbook_owner(god_type god, spschool_flag_type disc1,
 // that includes Statue Form and is named after her.
 void make_book_roxanne_special(item_def *book)
 {
-    spschool_flag_type disc = coinflip() ? SPTYP_TRANSMUTATION : SPTYP_EARTH;
+    spschool_flag_type disc = random_choose(SPTYP_TRANSMUTATION, SPTYP_EARTH);
     vector<spell_type> forced_spell = {SPELL_STATUE_FORM};
     build_themed_book(*book,
                       forced_spell_filter(forced_spell,
