@@ -24,8 +24,9 @@
 #include "files.h"
 #include "food.h"
 #include "invent.h"
-#include "itemname.h"
-#include "itemprop.h"
+#include "item-name.h"
+#include "item-prop.h"
+#include "item-status-flag-type.h"
 #include "items.h"
 #include "libutil.h"
 #include "macro.h"
@@ -80,11 +81,15 @@ int artefact_value(const item_def &item)
     // Brands are already accounted for via existing ego checks
 
     // This should probably be more complex... but this isn't so bad:
-    ret += 6 * prop[ ARTP_AC ] + 6 * prop[ ARTP_EVASION ]
+    ret += 6 * prop[ ARTP_AC ]
+            + 6 * prop[ ARTP_EVASION ]
             + 4 * prop[ ARTP_SHIELDING ]
             + 6 * prop[ ARTP_SLAYING ]
-            + 3 * prop[ ARTP_STRENGTH ] + 3 * prop[ ARTP_INTELLIGENCE ]
-            + 3 * prop[ ARTP_DEXTERITY ];
+            + 3 * prop[ ARTP_STRENGTH ]
+            + 3 * prop[ ARTP_INTELLIGENCE ]
+            + 3 * prop[ ARTP_DEXTERITY ]
+            + 4 * prop[ ARTP_HP ]
+            + 3 * prop[ ARTP_MAGICAL_POWER ];
 
     // These resistances have meaningful levels
     if (prop[ ARTP_FIRE ] > 0)
@@ -173,13 +178,12 @@ int artefact_value(const item_def &item)
     if (prop[ ARTP_FRAGILE ])
         ret -= 8;
 
-    // extremely good
-    if (prop[ ARTP_FOG ])
-        ret += 50;
-
     if (prop[ ARTP_RMSL ])
         ret += 20;
 
+    if (prop[ ARTP_CLARITY ])
+        ret += 20;
+
     return (ret > 0) ? ret : 0;
 }
 
@@ -222,6 +226,8 @@ unsigned int item_value(item_def item, bool ident)
             case SPWPN_DISTORTION:
             case SPWPN_ELECTROCUTION:
             case SPWPN_PAIN:
+            case SPWPN_ACID: // Unrand-only.
+            case SPWPN_PENETRATION: // Unrand-only.
                 valued *= 25;
                 break;
 
@@ -264,7 +270,7 @@ unsigned int item_value(item_def item, bool ident)
         else if (!(item.flags & ISFLAG_IDENT_MASK)
                  && (get_equip_desc(item) != 0))
         {
-            valued += 60; // un-id'd "glowing" - arbitrary added cost
+            valued += 30; // un-id'd "glowing" - arbitrary added cost
         }
 
         if (item_known_cursed(item))
@@ -348,6 +354,7 @@ unsigned int item_value(item_def item, bool ident)
             case SPARM_MAGIC_RESISTANCE:
             case SPARM_PROTECTION:
             case SPARM_ARCHERY:
+            case SPARM_REPULSION:
                 valued += 50;
                 break;
 
@@ -379,7 +386,7 @@ unsigned int item_value(item_def item, bool ident)
         else if (!(item.flags & ISFLAG_IDENT_MASK)
                  && (get_equip_desc(item) != 0))
         {
-            valued += 60; // un-id'd "glowing" - arbitrary added cost
+            valued += 30; // un-id'd "glowing" - arbitrary added cost
         }
 
         if (item_known_cursed(item))
@@ -398,13 +405,8 @@ unsigned int item_value(item_def item, bool ident)
             bool good = false;
             switch (item.sub_type)
             {
-            case WAND_HASTING:
-            case WAND_HEAL_WOUNDS:
-                valued += 240;
-                good = true;
-                break;
-
-            case WAND_TELEPORTATION:
+            case WAND_CLOUDS:
+            case WAND_SCATTERSHOT:
                 valued += 120;
                 good = true;
                 break;
@@ -429,7 +431,6 @@ unsigned int item_value(item_def item, bool ident)
                 break;
 
             case WAND_CONFUSION:
-            case WAND_SLOWING:
                 valued += 15;
                 break;
 
@@ -466,7 +467,6 @@ unsigned int item_value(item_def item, bool ident)
             case POT_GAIN_DEXTERITY:
             case POT_GAIN_INTELLIGENCE:
             case POT_GAIN_STRENGTH:
-#endif
             case POT_BENEFICIAL_MUTATION:
                 valued += 350;
                 break;
@@ -474,6 +474,7 @@ unsigned int item_value(item_def item, bool ident)
             case POT_CURE_MUTATION:
                 valued += 250;
                 break;
+#endif
 
             case POT_RESISTANCE:
             case POT_HASTE:
@@ -484,6 +485,7 @@ unsigned int item_value(item_def item, bool ident)
             case POT_INVISIBILITY:
             case POT_CANCELLATION:
             case POT_AMBROSIA:
+            case POT_MUTATION:
                 valued += 80;
                 break;
 
@@ -507,10 +509,6 @@ unsigned int item_value(item_def item, bool ident)
                 valued += 30;
                 break;
 
-            case POT_MUTATION:
-                valued += 25;
-                break;
-
 #if TAG_MAJOR_VERSION == 34
             case POT_POISON:
             case POT_STRONG_POISON:
@@ -544,15 +542,13 @@ unsigned int item_value(item_def item, bool ident)
             valued = 20;
             break;
 
-        case FOOD_BEEF_JERKY:
-        case FOOD_PIZZA:
         case FOOD_FRUIT:
             valued = 15;
             break;
 
         case FOOD_CHUNK:
         default:
-                break;
+            break;
         }
         break;
 
@@ -634,7 +630,8 @@ unsigned int item_value(item_def item, bool ident)
                     || item.sub_type == RING_EVASION
                     || item.sub_type == RING_DEXTERITY
                     || item.sub_type == RING_INTELLIGENCE
-                    || item.sub_type == RING_SLAYING))
+                    || item.sub_type == RING_SLAYING
+                    || item.sub_type == AMU_REFLECTION))
             {
                 // Formula: price = kn(n+1) / 2, where k depends on the subtype,
                 // n is the power. (The base variable is equal to 2n.)
@@ -655,6 +652,7 @@ unsigned int item_value(item_def item, bool ident)
                 case RING_STRENGTH:
                 case RING_DEXTERITY:
                 case RING_INTELLIGENCE:
+                case AMU_REFLECTION:
                     coefficient = 30;
                     break;
                 default:
@@ -689,7 +687,6 @@ unsigned int item_value(item_def item, bool ident)
                 case RING_PROTECTION_FROM_COLD:
                 case RING_PROTECTION_FROM_FIRE:
                 case RING_PROTECTION_FROM_MAGIC:
-                case AMU_REFLECTION:
                     valued += 250;
                     break;
 
@@ -748,6 +745,7 @@ unsigned int item_value(item_def item, bool ident)
         case MISC_FAN_OF_GALES:
         case MISC_PHIAL_OF_FLOODS:
         case MISC_LAMP_OF_FIRE:
+        case MISC_LIGHTNING_ROD:
             valued += 400;
             break;
 
@@ -756,7 +754,6 @@ unsigned int item_value(item_def item, bool ident)
             break;
 
         case MISC_BOX_OF_BEASTS:
-        case MISC_DISC_OF_STORMS:
         case MISC_SACK_OF_SPIDERS:
             valued += 200;
             break;
@@ -812,17 +809,6 @@ unsigned int item_value(item_def item, bool ident)
         valued = item_type_known(item) ? 250 : 120;
         break;
 
-    case OBJ_RODS:
-        if (!item_type_known(item))
-            valued = 120;
-        else
-            valued = 250;
-
-        // Both max charges and enchantment.
-        if (item_ident(item, ISFLAG_KNOW_PLUSES))
-            valued += 50 * (item.charge_cap / ROD_CHARGE_MULT + item.rod_plus);
-        break;
-
     case OBJ_ORBS:
         valued = 250000;
         break;
@@ -1859,7 +1845,6 @@ bool ShoppingList::cull_identical_items(const item_def& item, int cost)
         switch (item.sub_type)
         {
             case MISC_CRYSTAL_BALL_OF_ENERGY:
-            case MISC_DISC_OF_STORMS:
                 break;
             default:
                 if (!is_xp_evoker(item))
