@@ -11,11 +11,13 @@
 #include "cloud.h"
 #include "coord.h"
 #include "coordit.h"
-#include "dgnevent.h"
+#include "dgn-event.h"
 #include "dgn-overview.h"
 #include "dungeon.h"
-#include "itemprop.h"
+#include "item-prop.h"
+#include "level-state-type.h"
 #include "libutil.h"
+#include "map-knowledge.h"
 #include "mon-place.h"
 #include "options.h"
 #include "state.h"
@@ -139,11 +141,6 @@ static void _update_feat_at(const coord_def &gp)
     if (disjunction_haloed(gp))
         env.map_knowledge(gp).flags |= MAP_DISJUNCT;
 
-#if TAG_MAJOR_VERSION == 34
-    if (heated(gp))
-        env.map_knowledge(gp).flags |= MAP_HOT;
-#endif
-
     if (is_sanctuary(gp))
     {
         if (testbits(env.pgrid(gp), FPROP_SANCTUARY_1))
@@ -158,7 +155,7 @@ static void _update_feat_at(const coord_def &gp)
     if (you.get_fearmonger(gp))
         env.map_knowledge(gp).flags |= MAP_WITHHELD;
 
-    if (you.made_nervous_by(gp))
+    if (you.is_nervous() && you.see_cell(gp) && !monster_at(gp))
         env.map_knowledge(gp).flags |= MAP_WITHHELD;
 
     if ((feat_is_stone_stair(feat)
@@ -209,7 +206,9 @@ static show_item_type _item_to_show_code(const item_def &item)
     case OBJ_POTIONS:    return SHOW_ITEM_POTION;
     case OBJ_BOOKS:      return SHOW_ITEM_BOOK;
     case OBJ_STAVES:     return SHOW_ITEM_STAFF;
+#if TAG_MAJOR_VERSION == 34
     case OBJ_RODS:       return SHOW_ITEM_ROD;
+#endif
     case OBJ_MISCELLANY: return SHOW_ITEM_MISCELLANY;
     case OBJ_CORPSES:
         if (item.sub_type == CORPSE_SKELETON)
@@ -570,4 +569,9 @@ void show_update_emphasis()
     for (const stair_info &stair : stairs)
         if (stair.destination.is_valid())
             env.map_knowledge(stair.position).flags &= ~MAP_EMPHASIZE;
+
+    vector<transporter_info> transporters = level_info.get_transporters();
+    for (const transporter_info &transporter: transporters)
+        if (!transporter.destination.origin())
+            env.map_knowledge(transporter.position).flags &= ~MAP_EMPHASIZE;
 }
