@@ -4,6 +4,7 @@
 
 #include "beam.h"
 #include "stepdown.h"
+#include "zap-type.h"
 
 static pair<spell_type, zap_type> _spl_zaps[] =
 {
@@ -18,6 +19,7 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_BOLT_OF_FIRE, ZAP_BOLT_OF_FIRE },
     { SPELL_BOLT_OF_COLD, ZAP_BOLT_OF_COLD },
     { SPELL_PRIMAL_WAVE, ZAP_PRIMAL_WAVE },
+    { SPELL_SANDBLAST, ZAP_SANDBLAST },
     { SPELL_STONE_ARROW, ZAP_STONE_ARROW },
     { SPELL_POISON_ARROW, ZAP_POISON_ARROW },
     { SPELL_IRON_SHOT, ZAP_IRON_SHOT },
@@ -29,7 +31,6 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_FIREBALL, ZAP_FIREBALL },
     { SPELL_MEPHITIC_CLOUD, ZAP_MEPHITIC },
     { SPELL_VIOLENT_UNRAVELLING, ZAP_UNRAVELLING },
-    { SPELL_BOLT_OF_INACCURACY, ZAP_BOLT_OF_INACCURACY },
     { SPELL_DISPEL_UNDEAD, ZAP_DISPEL_UNDEAD },
     { SPELL_ISKENDERUNS_MYSTIC_BLAST, ZAP_ISKENDERUNS_MYSTIC_BLAST },
     { SPELL_AGONY, ZAP_AGONY },
@@ -55,7 +56,6 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_HASTE, ZAP_HASTE },
     { SPELL_INVISIBILITY, ZAP_INVISIBILITY },
     { SPELL_DIG, ZAP_DIG },
-    { SPELL_EXPLOSIVE_BOLT, ZAP_EXPLOSIVE_BOLT },
     { SPELL_CRYSTAL_BOLT, ZAP_CRYSTAL_BOLT },
     { SPELL_TUKIMAS_DANCE, ZAP_TUKIMAS_DANCE },
     { SPELL_CORROSIVE_BOLT, ZAP_CORROSIVE_BOLT },
@@ -79,13 +79,12 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_QUICKSILVER_BOLT, ZAP_BREATHE_POWER },
     { SPELL_STICKY_FLAME, ZAP_STICKY_FLAME },
     { SPELL_STICKY_FLAME_RANGE, ZAP_STICKY_FLAME_RANGE },
-    { SPELL_STICKY_FLAME_SPLASH, ZAP_BREATHE_STICKY_FLAME },
     { SPELL_DAZZLING_SPRAY, ZAP_DAZZLING_SPRAY },
     { SPELL_STEAM_BALL, ZAP_BREATHE_STEAM },
     { SPELL_ORB_OF_ELECTRICITY, ZAP_ORB_OF_ELECTRICITY },
     { SPELL_CHILLING_BREATH, ZAP_BREATHE_FROST },
-    { SPELL_MINOR_HEALING, ZAP_HEAL_WOUNDS },
     { SPELL_ICEBLAST, ZAP_ICEBLAST },
+    { SPELL_ACID_SPLASH, ZAP_BREATHE_ACID },
 };
 
 zap_type spell_to_zap(spell_type spell)
