@@ -30,10 +30,11 @@ game_state::game_state()
     : game_crashed(false), mouse_enabled(false), waiting_for_command(false),
       terminal_resized(false), last_winch(0), io_inited(false),
       need_save(false), saving_game(false), updating_scores(false),
-      seen_hups(0), map_stat_gen(false), obj_stat_gen(false),
-      type(GAME_TYPE_NORMAL), last_type(GAME_TYPE_UNSPECIFIED),
-      arena_suspended(false), generating_level(false), dump_maps(false),
-      test(false), script(false), build_db(false), tests_selected(),
+      seen_hups(0), map_stat_gen(false), map_stat_dump_disconnect(false),
+      obj_stat_gen(false), type(GAME_TYPE_NORMAL),
+      last_type(GAME_TYPE_UNSPECIFIED), arena_suspended(false),
+      generating_level(false), dump_maps(false), test(false), script(false),
+      build_db(false), tests_selected(),
 #ifdef DGAMELAUNCH
       throttle(true),
 #else
