@@ -14,8 +14,8 @@
 #include "libutil.h"
 #include "macro.h"
 #include "nearby-danger.h"
-#include "process_desc.h"
-#include "process_desc.h"
+#include "process-desc.h"
+#include "process-desc.h"
 #include "religion.h"
 #include "spl-cast.h"
 #include "terrain.h"
@@ -196,14 +196,7 @@ static bool _command_not_applicable(const command_type cmd, bool safe)
             return false;
         return true;
     case CMD_CAST_SPELL:
-        return // shamefully copied from _can_cast in spl-cast.cc
-            (you.form == TRAN_BAT || you.form == TRAN_PIG) ||
-            (you.duration[DUR_BRAINLESS]) ||
-            (you.no_cast()) ||
-            (!you.spell_no) ||
-            (you.berserk()) ||
-            (you.confused()) ||
-            (silenced(you.pos()));
+        return can_cast_spells(true);
     case CMD_DISPLAY_MAP:
         return tiles.get_map_display();
     case CMD_MAP_GOTO_TARGET:
