@@ -1,6 +1,5 @@
 #ifdef USE_TILE_LOCAL
-#ifndef TILEREG_DGN_H
-#define TILEREG_DGN_H
+#pragma once
 
 #include <vector>
 
@@ -74,4 +73,3 @@ protected:
 };
 
 #endif
-#endif
