@@ -1,6 +1,5 @@
 #ifdef USE_TILE_LOCAL
-#ifndef TILEREG_GRID_H
-#define TILEREG_GRID_H
+#pragma once
 
 #include "tiledgnbuf.h"
 #include "tilereg.h"
@@ -66,4 +65,3 @@ protected:
 };
 
 #endif
-#endif
