@@ -1,7 +1,7 @@
 #ifdef USE_TILE_LOCAL
-#ifndef TILEREG_TAB_H
-#define TILEREG_TAB_H
+#pragma once
 
+#include "command-type.h"
 #include "tilereg-grid.h"
 
 // A region that contains multiple region, selectable by tabs.
@@ -81,4 +81,3 @@ private:
 };
 
 #endif
-#endif
