@@ -1,6 +1,5 @@
 #ifdef USE_TILE_LOCAL
-#ifndef TILEREG_TEXT_H
-#define TILEREG_TEXT_H
+#pragma once
 
 #include "tilereg.h"
 
@@ -58,4 +57,3 @@ protected:
 };
 
 #endif
-#endif
