@@ -1,6 +1,5 @@
 #ifdef USE_TILE_LOCAL
-#ifndef TILEREG_H
-#define TILEREG_H
+#pragma once
 
 class ImageManager;
 struct MouseEvent;
@@ -101,4 +100,3 @@ public:
 };
 
 #endif
-#endif
