@@ -4,9 +4,10 @@
 **/
 
 #ifdef USE_TILE
-#ifndef TILESDL_H
-#define TILESDL_H
+#pragma once
 
+#include "cursor-type.h"
+#include "text-tag-type.h"
 #include "tilereg.h"
 
 class Popup;
@@ -289,4 +290,3 @@ protected:
 extern TilesFramework tiles;
 
 #endif
-#endif
