@@ -23,8 +23,8 @@
 #include "maps.h"
 #include "initfile.h"
 #include "libutil.h"
-#include "itemname.h"
-#include "itemprop.h"
+#include "item-name.h"
+#include "item-prop.h"
 #include "act-iter.h"
 #include "mon-death.h"
 #include "random.h"
@@ -1250,7 +1250,7 @@ int main(int argc, char* argv[])
         res2(LIGHTBLUE, drown, mon.res_water_drowning());
         res2(LIGHTRED, rot, mon.res_rotting());
         res2(LIGHTMAGENTA, neg, mon.res_negative_energy(true));
-        res2(YELLOW, cleanse, mon.res_holy_energy(&you));
+        res2(YELLOW, holy, mon.res_holy_energy());
         res2(LIGHTMAGENTA, torm, mon.res_torment());
         res2(LIGHTBLUE, wind, mon.res_wind());
         res2(LIGHTRED, napalm, mon.res_sticky_flame());
