@@ -223,14 +223,6 @@ define(function () {
         DEMON_1    : [0, 0x0E],
     });
 
-    // Mimics, 2 bits.
-    fg_flags.exclusive_flags.push({
-        mask        : [0, 0x60],
-        MIMIC_INEPT : [0, 0x20],
-        MIMIC       : [0, 0x40],
-        MIMIC_RAVEN : [0, 0x60],
-    });
-
     fg_flags.mask             = 0x0000FFFF;
 
     // Background flags
@@ -251,6 +243,7 @@ define(function () {
     bg_flags.flags.OOR        = 0x02000000;
     bg_flags.flags.WATER      = 0x04000000;
     bg_flags.flags.NEW_STAIR  = 0x08000000;
+    bg_flags.flags.NEW_TRANSPORTER = 0x10000000;
 
     // Kraken tentacle overlays.
     bg_flags.flags.KRAKEN_NW  = 0x20000000;
