@@ -412,8 +412,8 @@ int SDLWrapper::init(coord_def *m_windowsz, int *densityNum, int *densityDen)
         const int x = Options.tile_window_width;
         const int y = Options.tile_window_height;
         // By default, fill the whole screen.
-        m_windowsz->x = (x > 0) ? x : _desktop_width + x;
-        m_windowsz->y = (y > 0) ? y : _desktop_height + y;
+        m_windowsz->x = (x > 0) ? x : _desktop_width;
+        m_windowsz->y = (y > 0) ? y : _desktop_height;
     }
     else
     {
