@@ -1,5 +1,4 @@
-#ifndef WINDOWMANAGER_H
-#define WINDOWMANAGER_H
+#pragma once
 
 #ifdef USE_TILE_LOCAL
 
@@ -11,6 +10,7 @@ enum wm_event_type
     WME_ACTIVEEVENT,
     WME_KEYDOWN,
     WME_KEYUP,
+    WME_KEYPRESS,
     WME_MOUSEMOTION,
     WME_MOUSEBUTTONUP,
     WME_MOUSEBUTTONDOWN,
@@ -81,7 +81,7 @@ struct wm_event
 };
 
 // custom timer callback function
-typedef unsigned int (*wm_timer_callback)(unsigned int interval);
+typedef unsigned int (*wm_timer_callback)(unsigned int interval, void* param);
 
 class WindowManager
 {
@@ -96,7 +96,8 @@ public:
     static void shutdown();
 
     // Class functions
-    virtual int init(coord_def *m_windowsz) = 0;
+    virtual int init(coord_def *m_windowsz, int *densityNum,
+                     int *densityDen) = 0;
 
     // Environment state functions
     virtual void set_window_title(const char *title) = 0;
@@ -105,8 +106,9 @@ public:
     virtual void set_mod_state(key_mod mod) = 0;
 
     // System time functions
-    virtual void set_timer(unsigned int interval,
-                           wm_timer_callback callback) = 0;
+    virtual unsigned int set_timer(unsigned int interval,
+                                   wm_timer_callback callback) = 0;
+    virtual void remove_timer(unsigned int timer_id) = 0;
     virtual unsigned int get_ticks() const = 0;
     virtual void delay(unsigned int ms) = 0;
 
@@ -114,6 +116,7 @@ public:
     virtual int raise_custom_event() = 0;
     virtual int wait_event(wm_event *event) = 0;
     virtual unsigned int get_event_count(wm_event_type type) = 0;
+    virtual void show_keyboard() = 0;
 
     // Display functions
     virtual void resize(coord_def &m_windowsz) = 0;
@@ -127,7 +130,7 @@ public:
     virtual bool load_texture(GenericTexture *tex, const char *filename,
                               MipMapOptions mip_opt, unsigned int &orig_width,
                               unsigned int &orig_height,
-                              tex_proc_func proc = NULL,
+                              tex_proc_func proc = nullptr,
                               bool force_power_of_two = true) = 0;
 };
 
@@ -135,4 +138,3 @@ public:
 extern WindowManager *wm;
 
 #endif //USE_TILE_LOCAL
-#endif //include guard
