@@ -566,6 +566,16 @@ static void debug_load_map_by_name(string name, bool primary)
 
     if (primary)
     {
+        if (toplace->orient == MAP_ENCOMPASS
+            && !toplace->is_usable_in(level_id::current())
+            && !yesno("Warning: this is an encompass vault not designed "
+                       "for this location; placing it with &P may result in "
+                       "crashes and save corruption. Continue?", true, 'y'))
+        {
+            mprf("Ok; try placing with &L or go to the relevant location to "
+                 "safely place with &P.");
+            return;
+        }
         if (toplace->is_minivault())
             you.props["force_minivault"] = toplace->name;
         else
