@@ -18,9 +18,10 @@
 #include "dbg-util.h"
 #include "decks.h"
 #include "env.h"
-#include "godpassive.h"
+#include "god-passive.h"
 #include "invent.h"
-#include "itemprop.h"
+#include "item-prop.h"
+#include "item-status-flag-type.h"
 #include "items.h"
 #include "jobs.h"
 #include "libutil.h"
@@ -31,6 +32,7 @@
 #include "misc.h"
 #include "mon-death.h"
 #include "options.h"
+#include "orb-type.h"
 #include "output.h"
 #include "player-equip.h"
 #include "prompt.h"
@@ -99,8 +101,8 @@ void wizard_create_spec_object()
     do
     {
         mprf(MSGCH_PROMPT, ") - weapons     ( - missiles  [ - armour  / - wands    ?  - scrolls");
-        mprf(MSGCH_PROMPT, "= - jewellery   ! - potions   : - books   | - staves   \\  - rods");
-        mprf(MSGCH_PROMPT, "} - miscellany  X - corpses   %% - food    $ - gold     0  - the Orb");
+        mprf(MSGCH_PROMPT, "= - jewellery   ! - potions   : - books   | - staves   }  - miscellany");
+        mprf(MSGCH_PROMPT, "X - corpses     %% - food      $ - gold    0  - the Orb");
         mprf(MSGCH_PROMPT, "ESC - exit");
 
         msgwin_prompt("What class of item? ");
@@ -671,7 +673,7 @@ void wizard_make_object_randart()
 static bool _item_type_can_be_cursed(int type)
 {
     return type == OBJ_WEAPONS || type == OBJ_ARMOUR || type == OBJ_JEWELLERY
-           || type == OBJ_STAVES || type == OBJ_RODS;
+           || type == OBJ_STAVES;
 }
 
 void wizard_uncurse_item()
@@ -767,7 +769,7 @@ static int _subtype_index(int acq_type, const item_def &item)
     switch (acq_type)
     {
         case OBJ_MISCELLANY:
-            if (item.base_type == OBJ_RODS)
+            if (item.base_type == OBJ_WANDS)
                 return NUM_MISCELLANY + item.sub_type;
             break;
         case OBJ_STAVES:
@@ -790,7 +792,7 @@ static void _fill_item_from_subtype(object_class_type acq_type, int subtype,
         case OBJ_MISCELLANY:
             if (subtype >= NUM_MISCELLANY)
             {
-                item.base_type = OBJ_RODS;
+                item.base_type = OBJ_WANDS;
                 item.sub_type = subtype - NUM_MISCELLANY;
                 return;
             }
@@ -822,8 +824,8 @@ static void _debug_acquirement_stats(FILE *ostat)
     mitm[p].base_type = OBJ_UNASSIGNED;
 
     clear_messages();
-    mpr("[a] Weapons [b] Armours [c] Jewellery      [d] Books");
-    mpr("[e] Staves  [f] Wands   [g] Miscellaneous  [h] Food");
+    mpr("[a] Weapons [b] Armours   [c] Jewellery [d] Books");
+    mpr("[e] Staves  [f] Evocables [g] Food");
     mprf(MSGCH_PROMPT, "What kind of item would you like to get acquirement stats on? ");
 
     object_class_type type;
@@ -835,9 +837,8 @@ static void _debug_acquirement_stats(FILE *ostat)
     case 'c': type = OBJ_JEWELLERY;  break;
     case 'd': type = OBJ_BOOKS;      break;
     case 'e': type = OBJ_STAVES;     break;
-    case 'f': type = OBJ_WANDS;      break;
-    case 'g': type = OBJ_MISCELLANY; break;
-    case 'h': type = OBJ_FOOD;       break;
+    case 'f': type = OBJ_MISCELLANY; break;
+    case 'g': type = OBJ_FOOD;       break;
     default:
         canned_msg(MSG_OK);
         return;
@@ -889,7 +890,7 @@ static void _debug_acquirement_stats(FILE *ostat)
         acq_calls++;
         total_quant += item.quantity;
         // hack alert: put unrands into the end of staff acq
-        // and rods into the end of misc acq
+        // and wands into the end of misc acq
         const int subtype_index = _subtype_index(type, item);
         subtype_quants[subtype_index] += item.quantity;
 
@@ -1032,8 +1033,6 @@ static void _debug_acquirement_stats(FILE *ostat)
             for (int d = 0; d <= SPTYP_LAST_EXPONENT; ++d)
             {
                 const auto disc = spschools_type::exponent(d);
-                if (disc & SPTYP_DIVINATION)
-                    continue;
 
                 if (disciplines & disc)
                 {
@@ -1046,8 +1045,6 @@ static void _debug_acquirement_stats(FILE *ostat)
         for (int d = 0; d <= SPTYP_LAST_EXPONENT; ++d)
         {
             const auto disc = spschools_type::exponent(d);
-            if (disc & SPTYP_DIVINATION)
-                continue;
 
             fprintf(ostat, "%-13s:  %2d/%2d spells unseen\n",
                     spelltype_long_name(disc),
@@ -1159,6 +1156,8 @@ static void _debug_acquirement_stats(FILE *ostat)
 #if TAG_MAJOR_VERSION == 34
             "jumping",
 #endif
+            "repulsion",
+            "cloud immunity",
         };
 
         const int non_art = acq_calls - num_arts;
@@ -1190,7 +1189,6 @@ static void _debug_acquirement_stats(FILE *ostat)
                 "transmutation",
                 "necromancy",
                 "summoning",
-                "divination",
                 "translocation",
                 "poison magic",
                 "earth magic",
@@ -1460,9 +1458,6 @@ static void _debug_rap_stats(FILE *ostat)
         "ARTP_SEE_INVISIBLE",
         "ARTP_INVISIBLE",
         "ARTP_FLY",
-#if TAG_MAJOR_VERSION > 34
-        "ARTP_FOG",
-#endif
         "ARTP_BLINK",
         "ARTP_BERSERK",
         "ARTP_NOISE",
@@ -1627,4 +1622,22 @@ void wizard_unidentify_all_items()
     }
 }
 
+void wizard_recharge_evokers()
+{
+    for (int i = 0; i < NUM_MISCELLANY; ++i)
+    {
+        item_def dummy;
+        dummy.base_type = OBJ_MISCELLANY;
+        dummy.sub_type = i;
+
+        if (!is_xp_evoker(dummy))
+            continue;
+
+        evoker_debt(dummy.sub_type) = 0;
+
+        if (dummy.sub_type == MISC_LIGHTNING_ROD)
+            you.props["thunderbolt_charge"].get_int() = 0;
+    }
+    mpr("Evokers recharged.");
+}
 #endif
